@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.8 2006/02/13 17:42:46 khlut Exp $
+// $Id: main_thread.c,v 1.9 2006/03/15 19:23:04 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -281,7 +281,7 @@ NPError NP_GetValue(void *future, NPPVariable variable, void *value)
 
 NPError NP_Initialize(NPNetscapeFuncs * moz_funcs, NPPluginFuncs * plugin_funcs)
 {
-  void *ServiceManager;
+  void *ServiceManager=0;
   
   Debug("NP_Initialize\n");
   if (moz_funcs == NULL || plugin_funcs == NULL)
